import { KeepAliveToken } from "./keepalivetoken";
import { EtcdKV } from "./etcdkv";
import { EtcdOptions } from "./etcdoptions";
/**
 * etcd client using the grpc protocol of etcd version 3 and later.
 */
export declare class Etcd {
    static defaults: EtcdOptions;
    servers: string[];
    options: EtcdOptions;
    credentials: any;
    clients: any;
    clientLease: string;
    clientLeasePromise: Promise<string>;
    clientLeaseToken: KeepAliveToken;
    /** KeepAliveToken's created by this client */
    keepAlives: KeepAliveToken[];
    /**
     * Creates a new etcd client.
     * @param servers
     * array of etcd hosts to use
     *
     * **Note**: currently only the first server is used, this will be fixed before version 1
     * @param options - additional options, see {@link defaults} for actual defaults
     */
    constructor(servers?: string[], options?: EtcdOptions);
    private getBuffer(obj);
    private callClient(client, method, arg);
    private callClientStream(client, method);
    /**
     * closes the network connection and stops all keep alives started with this client.
     */
    close(): void;
    /**
     * get the managed client lease. If it isn't created yet, it will be created. The Client lease will be kept alive automatic.
     * @return lease ID
     */
    getClientLease(): Promise<string>;
    getSync(key: string, returnType?: "value"): string;
    getSync(key: string, returnType: "json"): any;
    getSync(key: string, returnType: "buffer"): Buffer;
    getSync(key: string, returnType: "raw"): EtcdKV;
    get(key: string, returnType?: "value"): Promise<string>;
    get(key: string, returnType: "json"): Promise<any>;
    get(key: string, returnType: "buffer"): Promise<Buffer>;
    get(key: string, returnType: "raw"): Promise<EtcdKV>;
    /**
     * blocking version of range()
     * @see {@link range}
     */
    rangeSync(fromKey: string, toKey: string, returnType?: "value" | "json" | "buffer" | "raw"): any;
    /**
     * get a range of key from etcd
     * @param fromKey - key to start from (inclusive)
     * @param toKey - key to end on (exclusive)
     * @param returnType
     * * `value` (default) - return the as a `string`
     * * `json` - parse as JSON and return the result
     * * `buffer` - return a NodeJS Buffer
     * * `raw` - return the value as it came from etcd
     * @return object with a key for each key returned, value of the key as defined by `returnType`
     */
    range(fromKey: string, toKey: string, returnType?: "value" | "json" | "buffer" | "raw"): Promise<any>;
    /**
     * blocking version of set()
     * @see {@link set}
     */
    setSync(key: string, value: any, lease?: number | string): string;
    /**
     * set a key/value to etcd.
     * * a `Buffer` is saved as-is
     * * `null` is saved as an empty string
     * * `undefined` is saved as an empty string
     * * strings are saved as-is
     * * everything else is tried to `JSON.stringify(value)`
     *
     * if you set "lease" to "client" a lease uniq to the instance of the Client will be used. This lease
     * will be created automatic and will be kept alive automatic.
     *
     * @param key - etcd key to set
     * @param value - content to set
     * @param lease - lease ID to use, or `client` to the client lease
     * @return lease ID used if any was used, else `null`
     */
    set(key: string, value: any, lease?: number | string): Promise<string>;
    /**
     * blocking version of delete()
     * @see {@link delete}
     */
    deleteSync(key: string, keyTo?: string): number;
    /**
     * delete a key from etcd.
     * @param key - key to start from (inclusive)
     * @param keyTo - key to end on (exclusive)
     * @return number of keys deleted
     */
    delete(key: string, keyTo?: string): Promise<number>;
    /**
     * blocking version of leaseGrant()
     * @see {@link leaseGrant}
     */
    leaseGrantSync(ttl: number): string;
    /**
     * request a new lease from etcd
     * @param ttl - requested TTL of the lease
     * @return
     */
    leaseGrant(ttl?: number): Promise<string>;
    /**
     * keep a lease alive
     * @param lease - lease to keep alive
     * @param interval - interval in which to send keep alives
     * @return `KeepAliveToken` that was created
     */
    leaseKeepAlive(lease: string, interval?: number): KeepAliveToken;
}
